@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
 __author__ = 'Ryota KAMOSHIDA'
-__version__ = '0.4.6'
+__version__ = '2.4.2'
 __license__ = 'MIT License: http://www.opensource.org/licenses/mit-license.php'
 
+
 # high level interface
-from malss import MALSS
+from .malss import MALSS
